======
Apyrat
======

.. image:: https://img.shields.io/pypi/v/apyrat.svg
        :target: https://pypi.python.org/pypi/apyrat


An Aparat video downloader. simple, but elegant.


Getting Started
---------------

you can install Apyrat from PyPi:

```
$ pip install -U apyrat
```

for example you want to download the video hosted `here <https://www.aparat.com/v/qur3I>`__. just run:

```
$ apyrat https://www.aparat.com/v/qur3I
```

you can also download playlists:

```
$ apyrat https://www.aparat.com/playlist/448747
```


Contributing
------------

Any contributions are welcome here! To learn how you can contribute, please check the `contributing doc: <https://github.com/CodeWithEmad/apyrat/blob/master/CONTRIBUTING.rst>`__.

License
-------

This work is licensed under the terms of the `MIT <https://github.com/CodeWithEmad/apyrat/blob/master/LICENSE>`_.
